#include "testlib.h"
#include <string>
#include <vector>
#include <utility>

const int MAXLEN = 100 * 1000 + 1;

class BigUnsigned {
  public:
    BigUnsigned() : digits(MAXLEN) { }

    BigUnsigned(const std::string &s) : digits(MAXLEN) {
      for (int i = s.size() - 1; i >= 0; --i) {
        digits[s.size() - 1 - i] = s[i] - '0';
      }
    }

    BigUnsigned operator+(const BigUnsigned &operand) const {
      BigUnsigned result = *this;
      int carry = 0;
      for (int i = 0; i < MAXLEN; ++i) {
        int sum = digits[i] + operand.digits[i] + carry;
        result.digits[i] = sum % 10;
        carry = sum / 10;
      }
      return result;
    }

    // operand is expected to be less than the number
    BigUnsigned operator-(const BigUnsigned &operand) const {
      BigUnsigned result = *this;
      int carry = 0;
      for (int i = 0; i < MAXLEN; ++i) {
        int diff = digits[i] - operand.digits[i] - carry;
        carry = 0;
        if (diff < 0) {
          diff += 10;
          carry = 1;
        }
        result.digits[i] = diff;
      }
      return result;
    }

    bool operator<(const BigUnsigned &operand) const {      
      for (int i = MAXLEN - 1; i >= 0; --i) {
        if (digits[i] < operand.digits[i]) {
          return true;
        } else if (digits[i] > operand.digits[i]) {
          return false;
        }
      }
      return false;
    }

    bool operator==(const BigUnsigned &operand) const {
      for (int i = MAXLEN - 1; i >= 0; --i) {
        if (digits[i] != operand.digits[i]) {
          return false;
        }
      }
      return true;
    }

    void reverse() {
      int right = 0, left = 0;
      for (int i = MAXLEN - 1; i >= 0; --i) {
        if (digits[i] != 0) {
          right = i;
          break;
        }
      }
      for ( ; left < right; ++left, --right) {
        std::swap(digits[left], digits[right]);
      }
    }

  private:
    std::vector<int> digits;
};

BigUnsigned read_big_unsigned(InStream &stream,
                              BigUnsigned minv, BigUnsigned maxv,
                              const std::string &variableName) {
  if (!stream.strict && stream.seekEof()) {
    stream.quitf(_unexpected_eof, "Unexpected end of file - big number expected");
  }  

  std::string number;
  stream.readWordTo(number);

  pattern digits("[0-9]+");
  if (!digits.matches(number)) {
    stream.quitf(_pe, ("Expected big unsigned integer, but \"" + __testlib_part(number) +
      "\" doesn't correspond to pattern \"" + digits.src() + "\"").c_str());
  }
  
  if (number.length() > 1 && number[0] == '0') {
      stream.quitf(_pe, ("Leading zeros detected in \"" + __testlib_part(number) + "\"").c_str());
  }

  BigUnsigned result(number);

  if (result < minv || maxv < result) {
    stream.quitf(_wa, "Integer violates the range");
  }

  return result;
}

const BigUnsigned ZERO = BigUnsigned("0");
const BigUnsigned ONE = BigUnsigned("1");
const BigUnsigned MAXN = BigUnsigned("1" + std::string(MAXLEN - 1, '0'));

// checker itself
BigUnsigned N;

// returns whether the answer exists and difference between big and small summands
std::pair<bool, BigUnsigned> read_answer(InStream &stream) {  
  BigUnsigned A = read_big_unsigned(stream, ZERO, MAXN, "A");

  if (A == ZERO) {
    return std::pair<bool, BigUnsigned>(false, ZERO);
  }

  BigUnsigned Ar = A;
  Ar.reverse();
  BigUnsigned S = A + Ar;
  if (!(S == N)) {
    stream.quitf(_wa, "The sum of answer and reverse is not equal to N");
  }
  if (A < Ar) {
    std::swap(A, Ar);
  }
  return std::pair<bool, BigUnsigned>(true, A - Ar);
}

int main(int argc, char **argv) {
  registerTestlibCmd(argc, argv);  
  N = read_big_unsigned(inf, ONE, MAXN, "N");

  std::pair<bool, BigUnsigned> jans = read_answer(ans);
  std::pair<bool, BigUnsigned> pans = read_answer(ouf);  

  if (jans.first > pans.first) {
    quitf(_wa, "jury has the decomposition, and participant not\n");
  } else if (jans.first == pans.first) {
    if (jans.first) {
      quitf(_ok, "decomposition exists\n");
    } else {
      quitf(_ok, "no decomposition\n");
    }
    
    /*
    if (jans.first) {
      // comparing decompositions
      if (jans.second < pans.second) {
        quitf(_wa, "jury has the better decomposition");
      }
      else if (jans.second == pans.second) {
        quitf(_ok, "same decompositions\n");
      }
      else { // (jans.second > pans.second)
        quitf(_fail, ":( participant has the better decomposition\n");
      }
    } else {
      quitf(_ok, "no decomposition\n", pans);
    }
    */
    
  } else { // (jans.first < pans.first)
    quitf(_fail, ":( participant has the decomposition and jury not\n");
  }  
}
